# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you don't want to build with hibernate cache provider, 
# while hibernate3 isn't available yet,
# give rpmbuild option '--without hibernate'

# BOOTSTRAP
%define _without_hibernate 1

%define with_hibernate %{!?_without_hibernate:1}%{?_without_hibernate:0}
%define without_hibernate %{?_without_hibernate:1}%{!?_without_hibernate:0}

# If you don't want to build with tests,
# give rpmbuild option '--without tests'

# BOOTSTRAP
%define _without_tests 1

%define with_tests %{!?_without_tests:1}%{?_without_tests:0}
%define without_tests %{?_without_tests:1}%{!?_without_tests:0}

%define section free

Summary:        Easy Hibernate Cache
Name:           ehcache
Version:        1.2.3
Release:        1jpp
Epoch:          0
License:        LGPL
URL:            http://ehcache.sourceforge.net/
Group:          Development/Libraries/Java
# svn export https://ehcache.svn.sourceforge.net/svnroot/ehcache/branches/ehcache-1.2.3
# tar cvf ehcache-1.2.3-src.tar.gz ehcache-1.2.3
Source0:        ehcache-1.2.3-src.tar.gz

Patch0:         ehcache-build_xml.patch
Patch1:         ehcache-build_properties.patch

BuildRequires:  java-devel >= 0:1.5
BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  junit
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  antlr
BuildRequires:  checkstyle
BuildRequires:  checkstyle-optional
BuildRequires:  jakarta-commons-beanutils
BuildRequires:  jakarta-commons-cli
BuildRequires:  jakarta-commons-collections
BuildRequires:  jakarta-commons-logging
# For the web tests
BuildRequires:  dom4j
BuildRequires:  httpunit
BuildRequires:  jakarta-commons-codec
BuildRequires:  jakarta-commons-httpclient
BuildRequires:  jtidy
BuildRequires:  rhino
BuildRequires:  servletapi4
# For the hibernate plugin
%if %{with_hibernate}
BuildRequires:  hibernate3
%endif

Requires:  /usr/sbin/update-alternatives
Requires:  jakarta-commons-collections
Requires:  jakarta-commons-logging
Provides:  hibernate_in_process_cache
Provides:  ehcache-bootstrap = 0:%{version}-%{release}
Obsoletes:  ehcache-bootstrap
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Ehcache is a pure Java, in-process cache with the following features:
   1. Fast
   2. Simple
   3. Acts as a pluggable cache for Hibernate 2.1, 3 and 3.1.
   4. Small foot print. Both in terms of size and memory requirements.
   5. Minimal dependencies.
   6. Fully documented. See the online Documentation, FAQ and the 
      online JavaDoc.
   7. Provides Memory and Disk stores.
   8. Comprehensively Test Coverage. See the clover test report.
   9. Scalable to hundreds of caches and large multi-cpu servers.
  10. Multiple CacheManagers per virtual machine (new in 1.2)
  11. Provides LRU, LFU and FIFO cache eviction policies. (new in 1.2)
  12. Persistent disk store which stores data between VM restarts.
  13. Supports the registration of CacheManager and CacheEventListener 
      for flexible integration(new in 1.2)
  14. Distributed caching, with fine grained control overf discovery 
      and delivery options.
  15. Pluggable distribution API  for extending distribution with 
      different mechanisms.
  16. Available under the Apache 1.1license. Ehcache's copyright and 
      licensing has been reviewed and approved by the Apache Software 
      Foundation, making ehcache suitable for use in Apache projects.
  17. Production tested. All final versions of ehcache are production 
      tested for several weeks on a large and very busy eCommerce site 
      before release.
  18. BlockingCache, SelfPopulatingCache, gzipping, caching Servlet 
      filters, and AsynchronousFaultTolerantCommandExecutor available 
      in the optional ehcache-constructs package.


%if %{with_hibernate}
%package hibernate
Summary:        Hibernate3 cache provider in %{name}
Group:          Development/Libraries/Java
Requires:	%{name} = 0:%{version}
Requires:	hibernate3

%description hibernate
%{summary}.
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

# FIXME The new manual requires apt
#%package manual
#Summary:        Documents for %{name}
#Group:          Development/Documentation

#%description manual
#%{summary}.

%prep
cat <<EOT

		If you don't want to build with hibernate cache provider, 
		while hibernate3 isn't available yet,
		give rpmbuild option '--without hibernate'

		If you don't want to build with tests,
		give rpmbuild option '--without tests'

EOT

%setup -q -n %{name}-%{version}
# remove all binary libs
#find . -name "*.jar" -exec rm -f {} \;
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done
for f in $(find . -name "*.java" -exec grep -l hibernate {} \;); do
    sed -e 's/net\.sf\.hibernate\./org.hibernate./' $f > tempf
    cp tempf $f
done
rm tempf

%patch0 -b .sav
%patch1 -b .sav


%build
mkdir -p build/test-classes
export OPT_JAR_LIST="antlr checkstyle ant/ant-junit junit commons-beanutils commons-logging"
pushd lib
ln -sf $(build-classpath commons-collections) .
ln -sf $(build-classpath commons-logging) .
popd
pushd tools
# FIXME 1.2.3 added more dependencies, some we don't have
ln -sf $(build-classpath antlr) .
mv aptall.jar.no aptall.jar
mv cenquatasks.jar.no cenquatasks.jar
ln -sf $(build-classpath checkstyle) .
ln -sf $(build-classpath checkstyle-optional) .
mv clover-1.3.12.jar.no clover-1.3.12.jar
ln -sf $(build-classpath commons-beanutils) .
ln -sf $(build-classpath commons-cli) .
%if %{with_hibernate}
ln -sf $(build-classpath hibernate3) .
%endif
ln -sf $(build-classpath regexp) .
mv jcache.jar.no jcache.jar
ln -sf $(build-classpath junit) .
ln -sf $(build-classpath xerces-j2) .
ln -sf $(build-classpath xml-commons-apis) .
popd
pushd tools/web
ln -sf $(build-classpath commons-codec) .
ln -sf $(build-classpath commons-httpclient) .
ln -sf $(build-classpath dom4j) .
ln -sf $(build-classpath httpunit) .
ln -sf $(build-classpath rhino) .
ln -sf $(build-classpath servletapi4) .
ln -sf $(build-classpath jtidy) .
popd
pushd tools/ydoc-2.2_02-jdk1.5/lib
mv class2svg.jar.no class2svg.jar
mv styleed.jar.no styleed.jar
mv ydoc.jar.no ydoc.jar
popd
export JAVA_HOME=/usr/lib/jvm/java-1.5.0
%if %{with_tests}
%if %{with_hibernate}
    ant compile javadoc dist-jar run-tests-no-check hibernate-jar run-hibernate-tests-no-check
%else
    ant compile javadoc dist-jar run-tests-no-check
%endif
%else
%if %{with_hibernate}
    ant compile javadoc dist-jar hibernate-jar
%else
    ant compile javadoc dist-jar
%endif
%endif

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p target/dist/%{name}-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%if %{with_hibernate}
cp -p target/dist/%{name}-hibernate-%{version}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-hibernate-%{version}.jar
%endif
(cd $RPM_BUILD_ROOT%{_javadir} 
  ln -sf %{name}-%{version}.jar %{name}.jar
%if %{with_hibernate}
  ln -sf %{name}-hibernate-%{version}.jar %{name}-hibernate.jar
%endif
)

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/site/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink
rm -rf doc/api

# License
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

# manual
#cp -pr site/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

# hibernate_in_process_cache ghost symlink
ln -s %{_sysconfdir}/alternatives \
  $RPM_BUILD_ROOT%{_javadir}/hibernate_in_process_cache.jar

%clean
rm -rf $RPM_BUILD_ROOT

%post
update-alternatives --install %{_javadir}/hibernate_in_process_cache.jar \
  hibernate_in_process_cache %{_javadir}/%{name}.jar 90

%preun
{
  [ $1 -eq 0 ] || exit 0
  update-alternatives --remove hibernate_in_process_cache %{_javadir}/%{name}.jar
} >/dev/null 2>&1 || :

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}/LICENSE.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%ghost %{_javadir}/hibernate_in_process_cache.jar

%if %{with_hibernate}
%files hibernate
%defattr(0644,root,root,0755)
%{_javadir}/%{name}-hibernate-%{version}.jar
%{_javadir}/%{name}-hibernate.jar
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

#%files manual
#%defattr(0644,root,root,0755)
#%{_docdir}/%{name}-%{version}

%changelog
* Thu Jun 07 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.2.3-1jpp
- Upgrade to 1.2.3
- Disable manual subpackage as it requires apt to build
- Build without hibernate and tests for bootstrapping purposes

* Wed Jun 06 2007 Fernando Nasser <fnasser@redhat.com> - 0:1.2-1jpp.ep1.1
- Add missing BR for checkstyle-optional
- Rebuild

* Mon Jul 10 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.2-1jpp_1rh
- Get Java 5 version from upstream

* Wed Jun 21 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.2-1jpp
- Upgrade to 1.2

* Tue Feb 28 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.1-4jpp_2rh
- Rebuild with Hibernate

* Tue Feb 28 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.1-4jpp_1rh
- First Red Hat build
- Disable ehcache-tests patch

* Tue Feb 28 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.1-4jpp
- Re-add patch to fix tests so that they build on JRockit

* Thu Feb 16 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.1-3jpp
- Patch the checkstyle config to build with checkstyle-4.1
- Enable failOnViolation of checkstyle target
- Drop ehcache-test.patch: some platform dependency ?
- Reduce requires
- Add -hibernate subpackage for hibernate provider (patched to hibernate3)
- Add option --without hibernate for bootstrap purposes

* Thu Jan 05 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.1-2jpp
- First JPP 1.7 build
- Do not support hibernate 2 any longer

* Tue Nov 01 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.1-1jpp
- Upgrade to 1.1

* Sat Jul 09 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.0-2jpp
- Inhibit failure due to checkstyle

* Tue Dec 14 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0-1jpp
- Upgrade to 1.0
- Drop many wrong Requires and BuildRequires

* Mon Sep 13 2004 Ralph Apel <r.apel at r-apel.de> - 0:0.9-1jpp
- Upgrade to 0.9
- Drop saxpath requirements
- Require jaxen >= 1.1

* Mon Aug 23 2004 Ralph Apel <r.apel at r-apel.de> - 0:0.8-3jpp
- Build with ant-1.6.2

* Fri Jul 02 2004 Ralph Apel <r.apel at r-apel.de> - 0:0.8-2jpp
- Relax some versioned dependencies
- Provide hibernate_in_process_cache and do update-alternatives, prio 90
- Continue providing ehcache-bootstrap but obsolete package ehcache-bootstrap
- Fix jboss4 dependencies to = 4.0.0

* Thu Jun 10 2004 Ralph Apel <r.apel at r-apel.de> - 0:0.8-1jpp
- First JPackage release.
